/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2015.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#ifndef __FWATOMSFILTER_NAMESPACE_HPP__
#define __FWATOMSFILTER_NAMESPACE_HPP__

/**
 * @brief Proposes an API to filter atoms.
 * @namespace fwAtomsFilter
 */
namespace fwAtomsFilter
{

/**
 * @brief       Contains fwAtomsFilter::factory utilities
 * @namespace   factory
 */
namespace factory
{
} // namespace factory

/**
 * @brief       Contains fwAtomsFilter::registry details
 * @namespace   registry
 */
namespace registry
{
} // namespace registry

} // namespace fwAtomsFilter

#endif /* __FWATOMSFILTER_NAMESPACE_HPP__ */

